From b03a8bd3e85164d35600ab8c90c0043b57a6a523 Mon Sep 17 00:00:00 2001
From: ibelyaev <Ivan.Belyaev@cern.ch>
Date: Mon, 23 Jan 2017 14:48:32 +0100
Subject: [PATCH] PhysConf.Selections: add ValidBPVSelection: - a variant of
 filter-selection to check the validity of the associated best primary vertex

---
 Phys/PhysConf/python/PhysConf/Selections.py | 28 +++++++++++----------
 1 file changed, 15 insertions(+), 13 deletions(-)

diff --git a/Phys/PhysConf/python/PhysConf/Selections.py b/Phys/PhysConf/python/PhysConf/Selections.py
index b07e0aedd..e8df05c31 100755
--- a/Phys/PhysConf/python/PhysConf/Selections.py
+++ b/Phys/PhysConf/python/PhysConf/Selections.py
@@ -15,7 +15,8 @@
 # - FilterSelection          : selection with FilterDesktop    algorithm 
 # - CombineSelection         : selection with CombineParticles algorithm 
 # - Combine3BodySelection    : selection with DaVinci::N3BodyDecays algorithm 
 # - Combine4BodySelection    : selection with DaVinci::N4BodyDecays algorithm 
 # - TupleSelection           : selection with DecayTreeTuple algorithm 
 # - PrintSelection           : helper selection for debugging purposes
 # - LimitSelection           : limit selection 
@@ -23,18 +24,18 @@
 # - MomentumScaling          : insert momentum scaling  into selection sequence
 # - MomentumSmear            : insert momentum smearing into selection sequence
 # - RebuildSelection         : re-run/re-build some existing common/standard selections
-# - TriggerSelection     : "event" selection to require certain trigger decisions
-# - L0Selection          : specialization of TriggerSelection for L0-trigger 
-# - Hlt1Selection        : specialization of TriggerSelection for Hlt1-trigger 
-# - Hlt2Selection        : specialization of TriggerSelection for Hlt2-trigger 
-# - StrippingSelection   : specialization of TriggerSelection for Stripping 
-# - TisTosSelection    : Specialization of FilterSelection for Tis/Tos/Tus/Tps-selections
-# - L0TOSSelection     : Specialization of TisTosSelection for L0-TOS 
-# - L0TISSelection     : Specialization of TisTosSelection for L0-TIS 
-# - Hlt1TOSSelection   : Specialization of TisTosSelection for Hlt1-TOS 
-# - Hlt1TISSelection   : Specialization of TisTosSelection for Hlt1-TIS 
-# - Hlt2TOSSelection   : Specialization of TisTosSelection for Hlt2-TOS 
-# - Hlt2TISSelection   : Specialization of TisTosSelection for Hlt2-TIS
+# - TriggerSelection         : "event" selection to require certain trigger decisions
+# - L0Selection              : specialization of TriggerSelection for L0-trigger 
+# - Hlt1Selection            : specialization of TriggerSelection for Hlt1-trigger 
+# - Hlt2Selection            : specialization of TriggerSelection for Hlt2-trigger 
+# - StrippingSelection       : specialization of TriggerSelection for Stripping 
+# - TisTosSelection          : specialization of FilterSelection for Tis/Tos/Tus/Tps-selections
+# - L0TOSSelection           : specialization of TisTosSelection for L0-TOS 
+# - L0TISSelection           : specialization of TisTosSelection for L0-TIS 
+# - Hlt1TOSSelection         : specialization of TisTosSelection for Hlt1-TOS 
+# - Hlt1TISSelection         : specialization of TisTosSelection for Hlt1-TIS 
+# - Hlt2TOSSelection         : specialization of TisTosSelection for Hlt2-TOS 
+# - Hlt2TISSelection         : specialization of TisTosSelection for Hlt2-TIS
 #
 #  @author Juan  PALACIOS 
 #  @author Vanya BELYAEV Ivan.Belyaev@itep.ru
@@ -94,6 +95,7 @@ __all__     = ( 'AutomaticData'                 ,
                 'Combine3BodySelection'         ,
                 'Combine4BodySelection'         ,
                 'TupleSelection'                ,
+                'ValidBPVSelection'             , 
                 ##
                 'CheckPVSelection'              ,
                 ##
@@ -15,7 +15,8 @@
 # - CombineSelection         : selection with CombineParticles algorithm 
 # - Combine3BodySelection    : selection with DaVinci::N3BodyDecays algorithm 
-# - Combine4BodySelection    : selection with DaVinci::N4BodyDecays algorithm 
+# - Combine4BodySelection    : selection with DaVinci::N4BodyDecays algorithm
+# - ValidBPVSelection        : check valid associated best primary vertex 
 # - TupleSelection           : selection with DecayTreeTuple algorithm 
 # - PrintSelection           : helper selection for debugging purposes
-- 
GitLab